@@ -8,10 +8,10 @@
 #' @param nsim Number of patterns to simulate.
 #' @param heterogenous If TRUE, points with the mark i are randomized using a heterogeneous
 #' Poisson process.
-#' @param ... Arguments passed to \code{spatstat.core::density.ppp()}.
+#' @param ... Arguments passed to \code{spatstat.explore::density.ppp()}.
 #'
 #' @details
-#' Simulate point patterns as null model data for \code{spatstat.core::envelope()} using
+#' Simulate point patterns as null model data for \code{spatstat.explore::envelope()} using
 #' antecedent conditions as null model. \code{x} must be marked point pattern.
 #' Antecedent conditions are suitable as a null model if points of type j may influence
 #' points of type i, but not the other way around (Velazquez et al 2016). One example are
@@ -33,7 +33,8 @@
 #' pattern <- spatstat.geom::superimpose(pattern_a, pattern_b)
 #'
 #' null_model <- simulate_antecedent_conditions(x = pattern, i = "b", j = "a", nsim = 19)
-#' spatstat.core::envelope(Y = pattern, fun = spatstat.core::pcf, nsim = 19, simulate = null_model)
+#' spatstat.explore::envelope(Y = pattern, fun = spatstat.explore::pcf,
+#' nsim = 19, simulate = null_model)
 #'
 #' @references
 #' Velázquez, E., Martínez, I., Getzin, S., Moloney, K.A., Wiegand, T., 2016. An evaluation
@@ -72,7 +73,7 @@ simulate_antecedent_conditions <- function(x, i, j, nsim, heterogenous = FALSE,
 
   if (heterogenous) {
 
-    lambda_xy <- spatstat.core::density.ppp(pattern_i, ...)
+    lambda_xy <- spatstat.explore::density.ppp(pattern_i, ...)
   }
 
   # create nsim patterns
